@@ -319,6 +319,13 @@ def _restore_wodoo_bin(ctx, config, filepath, verify):
 @click.option(
     "--verify", default=False, is_flag=True, help="Wodoo-bin: checks postgres version"
 )
+@click.option(
+    "-X",
+    "--exclude-tables",
+    multiple=True,
+    help="Exclude tables from restore like --exclude=mail_message",
+)
+@click.option("-v", "--verbose", is_flag=True)
 @pass_config
 @click.pass_context
 def restore_db(
@@ -329,6 +336,8 @@ def restore_db(
     no_remove_webassets,
     verify,
     workers,
+    exclude_tables,
+    verbose,
 ):
     if not filename:
         filename = _inquirer_dump_file(
@@ -457,7 +466,11 @@ def restore_db(
                     f"{parent_path_in_container}/{filename}",
                     "-j",
                     str(workers),
+                    "--exclude-tables",
+                    ",".join(exclude_tables),
                 ]
+                if verbose:
+                    cmd += ["--verbose"]
                 __dc(cmd)
             else:
                 _add_cronjob_scripts(config)["postgres"]._restore(
